# conjurer

Python library to help you to perform magic on your data analytics project; which helps
- EDA (load & check data)
- Automatic machine learning tuning

## Why do I need this?




## Reference

For installation / user guide please refer https://github.com/not-so-fat/conjurer/wiki
